@@ -328,7 +328,7 @@ def hash_onnx_object(obj, max_size):
         obj.doc_string = ''
         try:
             m.update(obj.SerializeToString())
-        except AttributeError as e:
+        except AttributeError as e:  # pragma: no cover
             raise RuntimeError(
                 "Unable to hash object type %r, value=%r."
                 "" % (type(obj), obj)) from e
@@ -354,7 +354,8 @@ def onnx_rename_names(model, strategy='simple', recursive=True,
     :param verbose: verbose, if positive, reports on all changed names
     :param fLOG: logging function
     :param counts: used for recursion
-    :param replace: used for recursion
+    :param replace: used for recursion, it can be also used to
+        to fix some replacements
     :param taken: used for recursion
     :return: onnx model (the model is modified in place)
 
